@@ -1,6 +1,6 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2013 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,7 +17,6 @@
 
 
 import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-dwh')
 
 
 from otopi import util
@@ -28,12 +27,25 @@ from ovirt_engine_setup import constants as osetupcons
 from ovirt_engine_setup.dwh import constants as odwhcons
 
 
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-engine-dwh')
+
+
 @util.export
 class Plugin(plugin.PluginBase):
 
     def __init__(self, context):
         super(Plugin, self).__init__(context=context)
 
+    @plugin.event(
+        stage=plugin.Stages.STAGE_INIT,
+    )
+    def _init(self):
+        self.environment.setdefault(
+            odwhcons.ConfigEnv.DWH_SERVICE_STOP_NEEDED,
+            False
+        )
+
     @plugin.event(
         stage=plugin.Stages.STAGE_TRANSACTION_BEGIN,
         before=(
@@ -41,6 +53,8 @@ class Plugin(plugin.PluginBase):
         ),
         condition=lambda self: not self.environment[
             osetupcons.CoreEnv.DEVELOPER_MODE
+        ] and self.environment[
+            odwhcons.ConfigEnv.DWH_SERVICE_STOP_NEEDED
         ],
     )
     def _transactionBegin(self):
